@matheusbsbs / matheus-bagliano / commits / 658dd48c85
Fork 0

Avoid unnecessary 'lstat()' calls in 'get_stat_data()'

When we ask get_stat_data() to get the mode and size of an index entry, we can avoid the lstat() call if we have marked the index entry as being uptodate due to earlier lstat() calls. This avoids a lot of unnecessary lstat() calls in eg 'git checkout', where the last phase shows the differences to the working tree (requiring a diff), but earlier phases have already verified the index. On the kernel repo (with a fast machine and everything cached), this changes timings of a nul 'git checkout' from - Before (best of ten): 0.14user 0.05system 0:00.19elapsed 100%CPU (0avgtext+0avgdata 0maxresident)k 0inputs+0outputs (0major+13237minor)pagefaults 0swaps - After 0.11user 0.03system 0:00.15elapsed 98%CPU (0avgtext+0avgdata 0maxresident)k 0inputs+0outputs (0major+13235minor)pagefaults 0swaps so it can obviously be noticeable, although equally obviously it's not a show-stopper on this particular machine. The difference is likely larger on slower machines, or with operating systems that don't do as good a job of name caching. Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org> Signed-off-by: Junio C Hamano <gitster@pobox.com>

Linus Torvalds committed May 9, 2009 at 14:57 UTC 658dd48c8572d0db49719cbef6605d384621d87c
1 file changed +1 -1
diff-lib.c
+1 -1
@@ -222,7 +222,7 @@ static int get_stat_data(struct cache_entry *ce,
222 const unsigned char *sha1 = ce->sha1;
223 unsigned int mode = ce->ce_mode;
224
225 - if (!cached) {
225 + if (!cached && !ce_uptodate(ce)) {
226 int changed;
227 struct stat st;
228 changed = check_removed(ce, &st);